@@ -163,9 +163,9 @@ sub get_vimeo_list_info {
                         if ( $el_title ) {
                             $entry->{title} = $el_title->attr( 'title' );
                         }
-                        my $el_published = $_->at( 'time' );
-                        if ( $el_published ) {
-                            $entry->{published} = $el_published->attr( 'datetime' );
+                        my $el_upload_date = $_->at( 'time' );
+                        if ( $el_upload_date ) {
+                            $entry->{upload_date} = $el_upload_date->attr( 'datetime' );
                         }
                         push @$tmp, $entry;
                     }
