@@ -183,8 +183,8 @@ sub read_json {
     flock $fh, LOCK_SH or die $!;
     my $json = do { local $/; <$fh> };
     close $fh;
-    my $h_ref = JSON->new->utf8->decode( $json ) if $json;
-    return $h_ref;
+    my $ref = JSON->new->utf8->decode( $json ) if $json;
+    return $ref;
 }
 
 
